# coding: utf-8
import pprint
import six
from enum import Enum
from . import TransactionAwareEntity


class ConnectorInvocation(TransactionAwareEntity):

    swagger_types = {
    
        'created_on': 'datetime',
        'planned_purge_date': 'datetime',
        'stage': 'ConnectorInvocationStage',
        'time_took_in_milliseconds': 'int',
        'transaction': 'int',
        'version': 'int',
    }

    attribute_map = {
        'created_on': 'createdOn','planned_purge_date': 'plannedPurgeDate','stage': 'stage','time_took_in_milliseconds': 'timeTookInMilliseconds','transaction': 'transaction','version': 'version',
    }

    
    _created_on = None
    _planned_purge_date = None
    _stage = None
    _time_took_in_milliseconds = None
    _transaction = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.created_on = kwargs.get('created_on', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.stage = kwargs.get('stage', None)
        self.time_took_in_milliseconds = kwargs.get('time_took_in_milliseconds', None)
        self.transaction = kwargs.get('transaction', None)
        self.version = kwargs.get('version', None)
        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def created_on(self):
        """Gets the created_on of this ConnectorInvocation.

            The created on date indicates the date on which the entity was stored into the database.

        :return: The created_on of this ConnectorInvocation.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this ConnectorInvocation.

            The created on date indicates the date on which the entity was stored into the database.

        :param created_on: The created_on of this ConnectorInvocation.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this ConnectorInvocation.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this ConnectorInvocation.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this ConnectorInvocation.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this ConnectorInvocation.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def stage(self):
        """Gets the stage of this ConnectorInvocation.

            

        :return: The stage of this ConnectorInvocation.
        :rtype: ConnectorInvocationStage
        """
        return self._stage

    @stage.setter
    def stage(self, stage):
        """Sets the stage of this ConnectorInvocation.

            

        :param stage: The stage of this ConnectorInvocation.
        :type: ConnectorInvocationStage
        """

        self._stage = stage
    
    @property
    def time_took_in_milliseconds(self):
        """Gets the time_took_in_milliseconds of this ConnectorInvocation.

            

        :return: The time_took_in_milliseconds of this ConnectorInvocation.
        :rtype: int
        """
        return self._time_took_in_milliseconds

    @time_took_in_milliseconds.setter
    def time_took_in_milliseconds(self, time_took_in_milliseconds):
        """Sets the time_took_in_milliseconds of this ConnectorInvocation.

            

        :param time_took_in_milliseconds: The time_took_in_milliseconds of this ConnectorInvocation.
        :type: int
        """

        self._time_took_in_milliseconds = time_took_in_milliseconds
    
    @property
    def transaction(self):
        """Gets the transaction of this ConnectorInvocation.

            

        :return: The transaction of this ConnectorInvocation.
        :rtype: int
        """
        return self._transaction

    @transaction.setter
    def transaction(self, transaction):
        """Sets the transaction of this ConnectorInvocation.

            

        :param transaction: The transaction of this ConnectorInvocation.
        :type: int
        """

        self._transaction = transaction
    
    @property
    def version(self):
        """Gets the version of this ConnectorInvocation.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this ConnectorInvocation.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ConnectorInvocation.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this ConnectorInvocation.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ConnectorInvocation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ConnectorInvocation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class CriteriaOperator(Enum):
    
    CONTAINS = "CONTAINS"
    EQUALS = "EQUALS"
    EQUALS_IGNORE_CASE = "EQUALS_IGNORE_CASE"
    GREATER_THAN = "GREATER_THAN"
    GREATER_THAN_OR_EQUAL = "GREATER_THAN_OR_EQUAL"
    LESS_THAN = "LESS_THAN"
    LESS_THAN_OR_EQUAL = "LESS_THAN_OR_EQUAL"
    NOT_EQUALS = "NOT_EQUALS"
    NOT_EQUALS_IGNORE_CASE = "NOT_EQUALS_IGNORE_CASE"
    NOT_CONTAINS = "NOT_CONTAINS"
    IS_NULL = "IS_NULL"
    IS_NOT_NULL = "IS_NOT_NULL"




# coding: utf-8
import pprint
import six
from enum import Enum



class ShopifySubscription:

    swagger_types = {
    
        'created_by': 'int',
        'created_on': 'datetime',
        'external_id': 'str',
        'id': 'int',
        'initial_execution_date': 'datetime',
        'initial_payment_transaction': 'int',
        'initial_shopify_transaction': 'int',
        'language': 'str',
        'linked_space_id': 'int',
        'order_recurrence_number': 'int',
        'shop': 'int',
        'state': 'ShopifySubscriptionState',
        'subscriber': 'ShopifySubscriber',
        'terminated_by': 'int',
        'terminated_on': 'datetime',
        'termination_request_date': 'datetime',
        'version': 'int',
    }

    attribute_map = {
        'created_by': 'createdBy','created_on': 'createdOn','external_id': 'externalId','id': 'id','initial_execution_date': 'initialExecutionDate','initial_payment_transaction': 'initialPaymentTransaction','initial_shopify_transaction': 'initialShopifyTransaction','language': 'language','linked_space_id': 'linkedSpaceId','order_recurrence_number': 'orderRecurrenceNumber','shop': 'shop','state': 'state','subscriber': 'subscriber','terminated_by': 'terminatedBy','terminated_on': 'terminatedOn','termination_request_date': 'terminationRequestDate','version': 'version',
    }

    
    _created_by = None
    _created_on = None
    _external_id = None
    _id = None
    _initial_execution_date = None
    _initial_payment_transaction = None
    _initial_shopify_transaction = None
    _language = None
    _linked_space_id = None
    _order_recurrence_number = None
    _shop = None
    _state = None
    _subscriber = None
    _terminated_by = None
    _terminated_on = None
    _termination_request_date = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.created_by = kwargs.get('created_by', None)
        self.created_on = kwargs.get('created_on', None)
        self.external_id = kwargs.get('external_id', None)
        self.id = kwargs.get('id', None)
        self.initial_execution_date = kwargs.get('initial_execution_date', None)
        self.initial_payment_transaction = kwargs.get('initial_payment_transaction', None)
        self.initial_shopify_transaction = kwargs.get('initial_shopify_transaction', None)
        self.language = kwargs.get('language', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.order_recurrence_number = kwargs.get('order_recurrence_number', None)
        self.shop = kwargs.get('shop', None)
        self.state = kwargs.get('state', None)
        self.subscriber = kwargs.get('subscriber', None)
        self.terminated_by = kwargs.get('terminated_by', None)
        self.terminated_on = kwargs.get('terminated_on', None)
        self.termination_request_date = kwargs.get('termination_request_date', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def created_by(self):
        """Gets the created_by of this ShopifySubscription.

            

        :return: The created_by of this ShopifySubscription.
        :rtype: int
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ShopifySubscription.

            

        :param created_by: The created_by of this ShopifySubscription.
        :type: int
        """

        self._created_by = created_by
    
    @property
    def created_on(self):
        """Gets the created_on of this ShopifySubscription.

            

        :return: The created_on of this ShopifySubscription.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this ShopifySubscription.

            

        :param created_on: The created_on of this ShopifySubscription.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def external_id(self):
        """Gets the external_id of this ShopifySubscription.

            The external id helps to identify the entity and a subsequent creation of an entity with the same ID will not create a new entity.

        :return: The external_id of this ShopifySubscription.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this ShopifySubscription.

            The external id helps to identify the entity and a subsequent creation of an entity with the same ID will not create a new entity.

        :param external_id: The external_id of this ShopifySubscription.
        :type: str
        """
        if external_id is not None and len(external_id) > 100:
            raise ValueError("Invalid value for `external_id`, length must be less than or equal to `100`")
        if external_id is not None and len(external_id) < 1:
            raise ValueError("Invalid value for `external_id`, length must be greater than or equal to `1`")

        self._external_id = external_id
    
    @property
    def id(self):
        """Gets the id of this ShopifySubscription.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this ShopifySubscription.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ShopifySubscription.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this ShopifySubscription.
        :type: int
        """

        self._id = id
    
    @property
    def initial_execution_date(self):
        """Gets the initial_execution_date of this ShopifySubscription.

            

        :return: The initial_execution_date of this ShopifySubscription.
        :rtype: datetime
        """
        return self._initial_execution_date

    @initial_execution_date.setter
    def initial_execution_date(self, initial_execution_date):
        """Sets the initial_execution_date of this ShopifySubscription.

            

        :param initial_execution_date: The initial_execution_date of this ShopifySubscription.
        :type: datetime
        """

        self._initial_execution_date = initial_execution_date
    
    @property
    def initial_payment_transaction(self):
        """Gets the initial_payment_transaction of this ShopifySubscription.

            

        :return: The initial_payment_transaction of this ShopifySubscription.
        :rtype: int
        """
        return self._initial_payment_transaction

    @initial_payment_transaction.setter
    def initial_payment_transaction(self, initial_payment_transaction):
        """Sets the initial_payment_transaction of this ShopifySubscription.

            

        :param initial_payment_transaction: The initial_payment_transaction of this ShopifySubscription.
        :type: int
        """

        self._initial_payment_transaction = initial_payment_transaction
    
    @property
    def initial_shopify_transaction(self):
        """Gets the initial_shopify_transaction of this ShopifySubscription.

            

        :return: The initial_shopify_transaction of this ShopifySubscription.
        :rtype: int
        """
        return self._initial_shopify_transaction

    @initial_shopify_transaction.setter
    def initial_shopify_transaction(self, initial_shopify_transaction):
        """Sets the initial_shopify_transaction of this ShopifySubscription.

            

        :param initial_shopify_transaction: The initial_shopify_transaction of this ShopifySubscription.
        :type: int
        """

        self._initial_shopify_transaction = initial_shopify_transaction
    
    @property
    def language(self):
        """Gets the language of this ShopifySubscription.

            

        :return: The language of this ShopifySubscription.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this ShopifySubscription.

            

        :param language: The language of this ShopifySubscription.
        :type: str
        """

        self._language = language
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this ShopifySubscription.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this ShopifySubscription.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this ShopifySubscription.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this ShopifySubscription.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def order_recurrence_number(self):
        """Gets the order_recurrence_number of this ShopifySubscription.

            

        :return: The order_recurrence_number of this ShopifySubscription.
        :rtype: int
        """
        return self._order_recurrence_number

    @order_recurrence_number.setter
    def order_recurrence_number(self, order_recurrence_number):
        """Sets the order_recurrence_number of this ShopifySubscription.

            

        :param order_recurrence_number: The order_recurrence_number of this ShopifySubscription.
        :type: int
        """

        self._order_recurrence_number = order_recurrence_number
    
    @property
    def shop(self):
        """Gets the shop of this ShopifySubscription.

            

        :return: The shop of this ShopifySubscription.
        :rtype: int
        """
        return self._shop

    @shop.setter
    def shop(self, shop):
        """Sets the shop of this ShopifySubscription.

            

        :param shop: The shop of this ShopifySubscription.
        :type: int
        """

        self._shop = shop
    
    @property
    def state(self):
        """Gets the state of this ShopifySubscription.

            

        :return: The state of this ShopifySubscription.
        :rtype: ShopifySubscriptionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ShopifySubscription.

            

        :param state: The state of this ShopifySubscription.
        :type: ShopifySubscriptionState
        """

        self._state = state
    
    @property
    def subscriber(self):
        """Gets the subscriber of this ShopifySubscription.

            

        :return: The subscriber of this ShopifySubscription.
        :rtype: ShopifySubscriber
        """
        return self._subscriber

    @subscriber.setter
    def subscriber(self, subscriber):
        """Sets the subscriber of this ShopifySubscription.

            

        :param subscriber: The subscriber of this ShopifySubscription.
        :type: ShopifySubscriber
        """

        self._subscriber = subscriber
    
    @property
    def terminated_by(self):
        """Gets the terminated_by of this ShopifySubscription.

            

        :return: The terminated_by of this ShopifySubscription.
        :rtype: int
        """
        return self._terminated_by

    @terminated_by.setter
    def terminated_by(self, terminated_by):
        """Sets the terminated_by of this ShopifySubscription.

            

        :param terminated_by: The terminated_by of this ShopifySubscription.
        :type: int
        """

        self._terminated_by = terminated_by
    
    @property
    def terminated_on(self):
        """Gets the terminated_on of this ShopifySubscription.

            

        :return: The terminated_on of this ShopifySubscription.
        :rtype: datetime
        """
        return self._terminated_on

    @terminated_on.setter
    def terminated_on(self, terminated_on):
        """Sets the terminated_on of this ShopifySubscription.

            

        :param terminated_on: The terminated_on of this ShopifySubscription.
        :type: datetime
        """

        self._terminated_on = terminated_on
    
    @property
    def termination_request_date(self):
        """Gets the termination_request_date of this ShopifySubscription.

            

        :return: The termination_request_date of this ShopifySubscription.
        :rtype: datetime
        """
        return self._termination_request_date

    @termination_request_date.setter
    def termination_request_date(self, termination_request_date):
        """Sets the termination_request_date of this ShopifySubscription.

            

        :param termination_request_date: The termination_request_date of this ShopifySubscription.
        :type: datetime
        """

        self._termination_request_date = termination_request_date
    
    @property
    def version(self):
        """Gets the version of this ShopifySubscription.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this ShopifySubscription.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ShopifySubscription.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this ShopifySubscription.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ShopifySubscription, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ShopifySubscription):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class Role:

    swagger_types = {
    
        'account': 'Account',
        'id': 'int',
        'name': 'DatabaseTranslatedString',
        'permissions': 'list[Permission]',
        'planned_purge_date': 'datetime',
        'state': 'RoleState',
        'two_factor_required': 'bool',
        'version': 'int',
    }

    attribute_map = {
        'account': 'account','id': 'id','name': 'name','permissions': 'permissions','planned_purge_date': 'plannedPurgeDate','state': 'state','two_factor_required': 'twoFactorRequired','version': 'version',
    }

    
    _account = None
    _id = None
    _name = None
    _permissions = None
    _planned_purge_date = None
    _state = None
    _two_factor_required = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.account = kwargs.get('account', None)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.permissions = kwargs.get('permissions', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.state = kwargs.get('state', None)
        self.two_factor_required = kwargs.get('two_factor_required', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def account(self):
        """Gets the account of this Role.

            The account to which this role belongs to. This role can only be assigned within the assigned account and the sub accounts of the assigned account.

        :return: The account of this Role.
        :rtype: Account
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this Role.

            The account to which this role belongs to. This role can only be assigned within the assigned account and the sub accounts of the assigned account.

        :param account: The account of this Role.
        :type: Account
        """

        self._account = account
    
    @property
    def id(self):
        """Gets the id of this Role.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this Role.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Role.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this Role.
        :type: int
        """

        self._id = id
    
    @property
    def name(self):
        """Gets the name of this Role.

            The name of this role is used to identify the role within administrative interfaces.

        :return: The name of this Role.
        :rtype: DatabaseTranslatedString
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Role.

            The name of this role is used to identify the role within administrative interfaces.

        :param name: The name of this Role.
        :type: DatabaseTranslatedString
        """

        self._name = name
    
    @property
    def permissions(self):
        """Gets the permissions of this Role.

            Set of permissions that are granted to this role.

        :return: The permissions of this Role.
        :rtype: list[Permission]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this Role.

            Set of permissions that are granted to this role.

        :param permissions: The permissions of this Role.
        :type: list[Permission]
        """

        self._permissions = permissions
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this Role.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this Role.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this Role.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this Role.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def state(self):
        """Gets the state of this Role.

            

        :return: The state of this Role.
        :rtype: RoleState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Role.

            

        :param state: The state of this Role.
        :type: RoleState
        """

        self._state = state
    
    @property
    def two_factor_required(self):
        """Gets the two_factor_required of this Role.

            Defines whether having been granted this role will force a user to use two-factor authentication.

        :return: The two_factor_required of this Role.
        :rtype: bool
        """
        return self._two_factor_required

    @two_factor_required.setter
    def two_factor_required(self, two_factor_required):
        """Sets the two_factor_required of this Role.

            Defines whether having been granted this role will force a user to use two-factor authentication.

        :param two_factor_required: The two_factor_required of this Role.
        :type: bool
        """

        self._two_factor_required = two_factor_required
    
    @property
    def version(self):
        """Gets the version of this Role.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this Role.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Role.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this Role.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(Role, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, Role):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentTerminalTransactionSummary:

    swagger_types = {
    
        'dcc_transaction_sums': 'list[PaymentTerminalDccTransactionSum]',
        'ended_on': 'datetime',
        'id': 'int',
        'linked_space_id': 'int',
        'number_of_transactions': 'int',
        'payment_terminal': 'int',
        'receipt': 'str',
        'started_on': 'datetime',
        'transaction_sums': 'list[PaymentTerminalTransactionSum]',
        'version': 'int',
    }

    attribute_map = {
        'dcc_transaction_sums': 'dccTransactionSums','ended_on': 'endedOn','id': 'id','linked_space_id': 'linkedSpaceId','number_of_transactions': 'numberOfTransactions','payment_terminal': 'paymentTerminal','receipt': 'receipt','started_on': 'startedOn','transaction_sums': 'transactionSums','version': 'version',
    }

    
    _dcc_transaction_sums = None
    _ended_on = None
    _id = None
    _linked_space_id = None
    _number_of_transactions = None
    _payment_terminal = None
    _receipt = None
    _started_on = None
    _transaction_sums = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.dcc_transaction_sums = kwargs.get('dcc_transaction_sums', None)
        self.ended_on = kwargs.get('ended_on', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.number_of_transactions = kwargs.get('number_of_transactions', None)
        self.payment_terminal = kwargs.get('payment_terminal', None)
        self.receipt = kwargs.get('receipt', None)
        self.started_on = kwargs.get('started_on', None)
        self.transaction_sums = kwargs.get('transaction_sums', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def dcc_transaction_sums(self):
        """Gets the dcc_transaction_sums of this PaymentTerminalTransactionSummary.

            

        :return: The dcc_transaction_sums of this PaymentTerminalTransactionSummary.
        :rtype: list[PaymentTerminalDccTransactionSum]
        """
        return self._dcc_transaction_sums

    @dcc_transaction_sums.setter
    def dcc_transaction_sums(self, dcc_transaction_sums):
        """Sets the dcc_transaction_sums of this PaymentTerminalTransactionSummary.

            

        :param dcc_transaction_sums: The dcc_transaction_sums of this PaymentTerminalTransactionSummary.
        :type: list[PaymentTerminalDccTransactionSum]
        """

        self._dcc_transaction_sums = dcc_transaction_sums
    
    @property
    def ended_on(self):
        """Gets the ended_on of this PaymentTerminalTransactionSummary.

            

        :return: The ended_on of this PaymentTerminalTransactionSummary.
        :rtype: datetime
        """
        return self._ended_on

    @ended_on.setter
    def ended_on(self, ended_on):
        """Sets the ended_on of this PaymentTerminalTransactionSummary.

            

        :param ended_on: The ended_on of this PaymentTerminalTransactionSummary.
        :type: datetime
        """

        self._ended_on = ended_on
    
    @property
    def id(self):
        """Gets the id of this PaymentTerminalTransactionSummary.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this PaymentTerminalTransactionSummary.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentTerminalTransactionSummary.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this PaymentTerminalTransactionSummary.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this PaymentTerminalTransactionSummary.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this PaymentTerminalTransactionSummary.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this PaymentTerminalTransactionSummary.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this PaymentTerminalTransactionSummary.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def number_of_transactions(self):
        """Gets the number_of_transactions of this PaymentTerminalTransactionSummary.

            

        :return: The number_of_transactions of this PaymentTerminalTransactionSummary.
        :rtype: int
        """
        return self._number_of_transactions

    @number_of_transactions.setter
    def number_of_transactions(self, number_of_transactions):
        """Sets the number_of_transactions of this PaymentTerminalTransactionSummary.

            

        :param number_of_transactions: The number_of_transactions of this PaymentTerminalTransactionSummary.
        :type: int
        """

        self._number_of_transactions = number_of_transactions
    
    @property
    def payment_terminal(self):
        """Gets the payment_terminal of this PaymentTerminalTransactionSummary.

            

        :return: The payment_terminal of this PaymentTerminalTransactionSummary.
        :rtype: int
        """
        return self._payment_terminal

    @payment_terminal.setter
    def payment_terminal(self, payment_terminal):
        """Sets the payment_terminal of this PaymentTerminalTransactionSummary.

            

        :param payment_terminal: The payment_terminal of this PaymentTerminalTransactionSummary.
        :type: int
        """

        self._payment_terminal = payment_terminal
    
    @property
    def receipt(self):
        """Gets the receipt of this PaymentTerminalTransactionSummary.

            

        :return: The receipt of this PaymentTerminalTransactionSummary.
        :rtype: str
        """
        return self._receipt

    @receipt.setter
    def receipt(self, receipt):
        """Sets the receipt of this PaymentTerminalTransactionSummary.

            

        :param receipt: The receipt of this PaymentTerminalTransactionSummary.
        :type: str
        """

        self._receipt = receipt
    
    @property
    def started_on(self):
        """Gets the started_on of this PaymentTerminalTransactionSummary.

            

        :return: The started_on of this PaymentTerminalTransactionSummary.
        :rtype: datetime
        """
        return self._started_on

    @started_on.setter
    def started_on(self, started_on):
        """Sets the started_on of this PaymentTerminalTransactionSummary.

            

        :param started_on: The started_on of this PaymentTerminalTransactionSummary.
        :type: datetime
        """

        self._started_on = started_on
    
    @property
    def transaction_sums(self):
        """Gets the transaction_sums of this PaymentTerminalTransactionSummary.

            

        :return: The transaction_sums of this PaymentTerminalTransactionSummary.
        :rtype: list[PaymentTerminalTransactionSum]
        """
        return self._transaction_sums

    @transaction_sums.setter
    def transaction_sums(self, transaction_sums):
        """Sets the transaction_sums of this PaymentTerminalTransactionSummary.

            

        :param transaction_sums: The transaction_sums of this PaymentTerminalTransactionSummary.
        :type: list[PaymentTerminalTransactionSum]
        """

        self._transaction_sums = transaction_sums
    
    @property
    def version(self):
        """Gets the version of this PaymentTerminalTransactionSummary.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this PaymentTerminalTransactionSummary.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PaymentTerminalTransactionSummary.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this PaymentTerminalTransactionSummary.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentTerminalTransactionSummary, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentTerminalTransactionSummary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class TransactionCompletionBehavior(Enum):
    
    COMPLETE_IMMEDIATELY = "COMPLETE_IMMEDIATELY"
    COMPLETE_DEFERRED = "COMPLETE_DEFERRED"
    USE_CONFIGURATION = "USE_CONFIGURATION"




# coding: utf-8
import pprint
import six
from enum import Enum
from . import TransactionAwareEntity


class ShopifyRecurringOrder(TransactionAwareEntity):

    swagger_types = {
    
        'billed_on': 'datetime',
        'checkout_token': 'str',
        'created_on': 'datetime',
        'failure_reason': 'FailureReason',
        'order_id': 'str',
        'order_name': 'str',
        'planned_execution_date': 'datetime',
        'planned_purge_date': 'datetime',
        'recurrence_number': 'int',
        'shop': 'int',
        'started_processing_on': 'datetime',
        'state': 'ShopifyRecurringOrderState',
        'subscription_version': 'ShopifySubscriptionVersion',
        'transaction': 'ShopifyTransaction',
    }

    attribute_map = {
        'billed_on': 'billedOn','checkout_token': 'checkoutToken','created_on': 'createdOn','failure_reason': 'failureReason','order_id': 'orderId','order_name': 'orderName','planned_execution_date': 'plannedExecutionDate','planned_purge_date': 'plannedPurgeDate','recurrence_number': 'recurrenceNumber','shop': 'shop','started_processing_on': 'startedProcessingOn','state': 'state','subscription_version': 'subscriptionVersion','transaction': 'transaction',
    }

    
    _billed_on = None
    _checkout_token = None
    _created_on = None
    _failure_reason = None
    _order_id = None
    _order_name = None
    _planned_execution_date = None
    _planned_purge_date = None
    _recurrence_number = None
    _shop = None
    _started_processing_on = None
    _state = None
    _subscription_version = None
    _transaction = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.billed_on = kwargs.get('billed_on', None)
        self.checkout_token = kwargs.get('checkout_token', None)
        self.created_on = kwargs.get('created_on', None)
        self.failure_reason = kwargs.get('failure_reason', None)
        self.order_id = kwargs.get('order_id', None)
        self.order_name = kwargs.get('order_name', None)
        self.planned_execution_date = kwargs.get('planned_execution_date', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.recurrence_number = kwargs.get('recurrence_number', None)
        self.shop = kwargs.get('shop', None)
        self.started_processing_on = kwargs.get('started_processing_on', None)
        self.state = kwargs.get('state', None)
        self.subscription_version = kwargs.get('subscription_version', None)
        self.transaction = kwargs.get('transaction', None)
        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def billed_on(self):
        """Gets the billed_on of this ShopifyRecurringOrder.

            

        :return: The billed_on of this ShopifyRecurringOrder.
        :rtype: datetime
        """
        return self._billed_on

    @billed_on.setter
    def billed_on(self, billed_on):
        """Sets the billed_on of this ShopifyRecurringOrder.

            

        :param billed_on: The billed_on of this ShopifyRecurringOrder.
        :type: datetime
        """

        self._billed_on = billed_on
    
    @property
    def checkout_token(self):
        """Gets the checkout_token of this ShopifyRecurringOrder.

            

        :return: The checkout_token of this ShopifyRecurringOrder.
        :rtype: str
        """
        return self._checkout_token

    @checkout_token.setter
    def checkout_token(self, checkout_token):
        """Sets the checkout_token of this ShopifyRecurringOrder.

            

        :param checkout_token: The checkout_token of this ShopifyRecurringOrder.
        :type: str
        """

        self._checkout_token = checkout_token
    
    @property
    def created_on(self):
        """Gets the created_on of this ShopifyRecurringOrder.

            

        :return: The created_on of this ShopifyRecurringOrder.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this ShopifyRecurringOrder.

            

        :param created_on: The created_on of this ShopifyRecurringOrder.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def failure_reason(self):
        """Gets the failure_reason of this ShopifyRecurringOrder.

            

        :return: The failure_reason of this ShopifyRecurringOrder.
        :rtype: FailureReason
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """Sets the failure_reason of this ShopifyRecurringOrder.

            

        :param failure_reason: The failure_reason of this ShopifyRecurringOrder.
        :type: FailureReason
        """

        self._failure_reason = failure_reason
    
    @property
    def order_id(self):
        """Gets the order_id of this ShopifyRecurringOrder.

            

        :return: The order_id of this ShopifyRecurringOrder.
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this ShopifyRecurringOrder.

            

        :param order_id: The order_id of this ShopifyRecurringOrder.
        :type: str
        """

        self._order_id = order_id
    
    @property
    def order_name(self):
        """Gets the order_name of this ShopifyRecurringOrder.

            

        :return: The order_name of this ShopifyRecurringOrder.
        :rtype: str
        """
        return self._order_name

    @order_name.setter
    def order_name(self, order_name):
        """Sets the order_name of this ShopifyRecurringOrder.

            

        :param order_name: The order_name of this ShopifyRecurringOrder.
        :type: str
        """

        self._order_name = order_name
    
    @property
    def planned_execution_date(self):
        """Gets the planned_execution_date of this ShopifyRecurringOrder.

            

        :return: The planned_execution_date of this ShopifyRecurringOrder.
        :rtype: datetime
        """
        return self._planned_execution_date

    @planned_execution_date.setter
    def planned_execution_date(self, planned_execution_date):
        """Sets the planned_execution_date of this ShopifyRecurringOrder.

            

        :param planned_execution_date: The planned_execution_date of this ShopifyRecurringOrder.
        :type: datetime
        """

        self._planned_execution_date = planned_execution_date
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this ShopifyRecurringOrder.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this ShopifyRecurringOrder.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this ShopifyRecurringOrder.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this ShopifyRecurringOrder.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def recurrence_number(self):
        """Gets the recurrence_number of this ShopifyRecurringOrder.

            

        :return: The recurrence_number of this ShopifyRecurringOrder.
        :rtype: int
        """
        return self._recurrence_number

    @recurrence_number.setter
    def recurrence_number(self, recurrence_number):
        """Sets the recurrence_number of this ShopifyRecurringOrder.

            

        :param recurrence_number: The recurrence_number of this ShopifyRecurringOrder.
        :type: int
        """

        self._recurrence_number = recurrence_number
    
    @property
    def shop(self):
        """Gets the shop of this ShopifyRecurringOrder.

            

        :return: The shop of this ShopifyRecurringOrder.
        :rtype: int
        """
        return self._shop

    @shop.setter
    def shop(self, shop):
        """Sets the shop of this ShopifyRecurringOrder.

            

        :param shop: The shop of this ShopifyRecurringOrder.
        :type: int
        """

        self._shop = shop
    
    @property
    def started_processing_on(self):
        """Gets the started_processing_on of this ShopifyRecurringOrder.

            

        :return: The started_processing_on of this ShopifyRecurringOrder.
        :rtype: datetime
        """
        return self._started_processing_on

    @started_processing_on.setter
    def started_processing_on(self, started_processing_on):
        """Sets the started_processing_on of this ShopifyRecurringOrder.

            

        :param started_processing_on: The started_processing_on of this ShopifyRecurringOrder.
        :type: datetime
        """

        self._started_processing_on = started_processing_on
    
    @property
    def state(self):
        """Gets the state of this ShopifyRecurringOrder.

            

        :return: The state of this ShopifyRecurringOrder.
        :rtype: ShopifyRecurringOrderState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ShopifyRecurringOrder.

            

        :param state: The state of this ShopifyRecurringOrder.
        :type: ShopifyRecurringOrderState
        """

        self._state = state
    
    @property
    def subscription_version(self):
        """Gets the subscription_version of this ShopifyRecurringOrder.

            

        :return: The subscription_version of this ShopifyRecurringOrder.
        :rtype: ShopifySubscriptionVersion
        """
        return self._subscription_version

    @subscription_version.setter
    def subscription_version(self, subscription_version):
        """Sets the subscription_version of this ShopifyRecurringOrder.

            

        :param subscription_version: The subscription_version of this ShopifyRecurringOrder.
        :type: ShopifySubscriptionVersion
        """

        self._subscription_version = subscription_version
    
    @property
    def transaction(self):
        """Gets the transaction of this ShopifyRecurringOrder.

            

        :return: The transaction of this ShopifyRecurringOrder.
        :rtype: ShopifyTransaction
        """
        return self._transaction

    @transaction.setter
    def transaction(self, transaction):
        """Sets the transaction of this ShopifyRecurringOrder.

            

        :param transaction: The transaction of this ShopifyRecurringOrder.
        :type: ShopifyTransaction
        """

        self._transaction = transaction
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ShopifyRecurringOrder, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ShopifyRecurringOrder):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractWebhookListenerUpdate:

    swagger_types = {
    
        'entity_states': 'list[str]',
        'name': 'str',
        'notify_every_change': 'bool',
        'state': 'CreationEntityState',
    }

    attribute_map = {
        'entity_states': 'entityStates','name': 'name','notify_every_change': 'notifyEveryChange','state': 'state',
    }

    
    _entity_states = None
    _name = None
    _notify_every_change = None
    _state = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.entity_states = kwargs.get('entity_states', None)
        self.name = kwargs.get('name', None)
        self.notify_every_change = kwargs.get('notify_every_change', None)
        self.state = kwargs.get('state', None)
        

    
    @property
    def entity_states(self):
        """Gets the entity_states of this AbstractWebhookListenerUpdate.

            The target state identifies the state into which entities need to move into to trigger the webhook listener.

        :return: The entity_states of this AbstractWebhookListenerUpdate.
        :rtype: list[str]
        """
        return self._entity_states

    @entity_states.setter
    def entity_states(self, entity_states):
        """Sets the entity_states of this AbstractWebhookListenerUpdate.

            The target state identifies the state into which entities need to move into to trigger the webhook listener.

        :param entity_states: The entity_states of this AbstractWebhookListenerUpdate.
        :type: list[str]
        """

        self._entity_states = entity_states
    
    @property
    def name(self):
        """Gets the name of this AbstractWebhookListenerUpdate.

            The webhook listener name is used internally to identify the webhook listener in administrative interfaces.For example it is used within search fields and hence it should be distinct and descriptive.

        :return: The name of this AbstractWebhookListenerUpdate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AbstractWebhookListenerUpdate.

            The webhook listener name is used internally to identify the webhook listener in administrative interfaces.For example it is used within search fields and hence it should be distinct and descriptive.

        :param name: The name of this AbstractWebhookListenerUpdate.
        :type: str
        """
        if name is not None and len(name) > 50:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `50`")

        self._name = name
    
    @property
    def notify_every_change(self):
        """Gets the notify_every_change of this AbstractWebhookListenerUpdate.

            Defines whether the webhook listener is to be informed about every change made to the entity in contrast to state transitions only.

        :return: The notify_every_change of this AbstractWebhookListenerUpdate.
        :rtype: bool
        """
        return self._notify_every_change

    @notify_every_change.setter
    def notify_every_change(self, notify_every_change):
        """Sets the notify_every_change of this AbstractWebhookListenerUpdate.

            Defines whether the webhook listener is to be informed about every change made to the entity in contrast to state transitions only.

        :param notify_every_change: The notify_every_change of this AbstractWebhookListenerUpdate.
        :type: bool
        """

        self._notify_every_change = notify_every_change
    
    @property
    def state(self):
        """Gets the state of this AbstractWebhookListenerUpdate.

            

        :return: The state of this AbstractWebhookListenerUpdate.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this AbstractWebhookListenerUpdate.

            

        :param state: The state of this AbstractWebhookListenerUpdate.
        :type: CreationEntityState
        """

        self._state = state
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractWebhookListenerUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractWebhookListenerUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8

from __future__ import absolute_import

import six

from postfinancecheckout.api_client import ApiClient

class ChargeBankTransactionServiceApi:

    def __init__(self, configuration):
        self.api_client = ApiClient(configuration=configuration)

    def count(self, space_id, **kwargs):
        """Count

        Counts the number of items in the database as restricted by the given filter.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.count(space_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQueryFilter filter: The filter which restricts the entities which are used to calculate the count.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.count_with_http_info(space_id, **kwargs)
        else:
            (data) = self.count_with_http_info(space_id, **kwargs)
            return data

    def count_with_http_info(self, space_id, **kwargs):
        """Count

        Counts the number of items in the database as restricted by the given filter.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.count_with_http_info(space_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQueryFilter filter: The filter which restricts the entities which are used to calculate the count.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'filter']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method count" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `count`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'filter' in params:
            body_params = params['filter']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/charge-bank-transaction/count', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='int',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def read(self, space_id, id, **kwargs):
        """Read

        Reads the entity with the given 'id' and returns it.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The ID of the charge bank transaction which should be returned. (required)
        :return: ChargeBankTransaction
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.read_with_http_info(space_id, id, **kwargs)
        else:
            (data) = self.read_with_http_info(space_id, id, **kwargs)
            return data

    def read_with_http_info(self, space_id, id, **kwargs):
        """Read

        Reads the entity with the given 'id' and returns it.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read_with_http_info(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The ID of the charge bank transaction which should be returned. (required)
        :return: ChargeBankTransaction
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `read`")
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `read`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'id' in params:
            query_params.append(('id', params['id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['*/*'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/charge-bank-transaction/read', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ChargeBankTransaction',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def search(self, space_id, query, **kwargs):
        """Search

        Searches for the entities as specified by the given query.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search(space_id, query, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQuery query: The query restricts the charge bank transactions which are returned by the search. (required)
        :return: list[ChargeBankTransaction]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.search_with_http_info(space_id, query, **kwargs)
        else:
            (data) = self.search_with_http_info(space_id, query, **kwargs)
            return data

    def search_with_http_info(self, space_id, query, **kwargs):
        """Search

        Searches for the entities as specified by the given query.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_with_http_info(space_id, query, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQuery query: The query restricts the charge bank transactions which are returned by the search. (required)
        :return: list[ChargeBankTransaction]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'query']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `search`")
        # verify the required parameter 'query' is set
        if ('query' not in params or
                params['query'] is None):
            raise ValueError("Missing the required parameter `query` when calling `search`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query' in params:
            body_params = params['query']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/charge-bank-transaction/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ChargeBankTransaction]',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8
import pprint
import six
from enum import Enum



class ChargeFlow:

    swagger_types = {
    
        'conditions': 'list[int]',
        'id': 'int',
        'linked_space_id': 'int',
        'name': 'str',
        'planned_purge_date': 'datetime',
        'priority': 'int',
        'state': 'CreationEntityState',
        'version': 'int',
    }

    attribute_map = {
        'conditions': 'conditions','id': 'id','linked_space_id': 'linkedSpaceId','name': 'name','planned_purge_date': 'plannedPurgeDate','priority': 'priority','state': 'state','version': 'version',
    }

    
    _conditions = None
    _id = None
    _linked_space_id = None
    _name = None
    _planned_purge_date = None
    _priority = None
    _state = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.conditions = kwargs.get('conditions', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.name = kwargs.get('name', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.priority = kwargs.get('priority', None)
        self.state = kwargs.get('state', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def conditions(self):
        """Gets the conditions of this ChargeFlow.

            If a transaction meets all selected conditions, the charge flow will be used to process the transaction. If the conditions are not met the next charge flow in line will be chosen according to the priorities.

        :return: The conditions of this ChargeFlow.
        :rtype: list[int]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this ChargeFlow.

            If a transaction meets all selected conditions, the charge flow will be used to process the transaction. If the conditions are not met the next charge flow in line will be chosen according to the priorities.

        :param conditions: The conditions of this ChargeFlow.
        :type: list[int]
        """

        self._conditions = conditions
    
    @property
    def id(self):
        """Gets the id of this ChargeFlow.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this ChargeFlow.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ChargeFlow.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this ChargeFlow.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this ChargeFlow.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this ChargeFlow.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this ChargeFlow.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this ChargeFlow.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def name(self):
        """Gets the name of this ChargeFlow.

            The charge flow name is used internally to identify the configuration in administrative interfaces. For example it is used within search fields and hence it should be distinct and descriptive.

        :return: The name of this ChargeFlow.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ChargeFlow.

            The charge flow name is used internally to identify the configuration in administrative interfaces. For example it is used within search fields and hence it should be distinct and descriptive.

        :param name: The name of this ChargeFlow.
        :type: str
        """

        self._name = name
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this ChargeFlow.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this ChargeFlow.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this ChargeFlow.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this ChargeFlow.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def priority(self):
        """Gets the priority of this ChargeFlow.

            The priority orders the charge flows. As such the priority determines together with the conditions the charge flow the selection mechanism for a particular transaction. A change of the priority affects all future selections.

        :return: The priority of this ChargeFlow.
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this ChargeFlow.

            The priority orders the charge flows. As such the priority determines together with the conditions the charge flow the selection mechanism for a particular transaction. A change of the priority affects all future selections.

        :param priority: The priority of this ChargeFlow.
        :type: int
        """

        self._priority = priority
    
    @property
    def state(self):
        """Gets the state of this ChargeFlow.

            

        :return: The state of this ChargeFlow.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ChargeFlow.

            

        :param state: The state of this ChargeFlow.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def version(self):
        """Gets the version of this ChargeFlow.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this ChargeFlow.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ChargeFlow.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this ChargeFlow.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ChargeFlow, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ChargeFlow):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class CompletionLineItem:

    swagger_types = {
    
        'amount': 'float',
        'quantity': 'float',
        'unique_id': 'str',
    }

    attribute_map = {
        'amount': 'amount','quantity': 'quantity','unique_id': 'uniqueId',
    }

    
    _amount = None
    _quantity = None
    _unique_id = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.amount = kwargs.get('amount', None)
        self.quantity = kwargs.get('quantity', None)
        self.unique_id = kwargs.get('unique_id', None)
        

    
    @property
    def amount(self):
        """Gets the amount of this CompletionLineItem.

            The total amount of the line item including any tax.

        :return: The amount of this CompletionLineItem.
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this CompletionLineItem.

            The total amount of the line item including any tax.

        :param amount: The amount of this CompletionLineItem.
        :type: float
        """

        self._amount = amount
    
    @property
    def quantity(self):
        """Gets the quantity of this CompletionLineItem.

            The quantity of the line item which should be completed.

        :return: The quantity of this CompletionLineItem.
        :rtype: float
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this CompletionLineItem.

            The quantity of the line item which should be completed.

        :param quantity: The quantity of this CompletionLineItem.
        :type: float
        """

        self._quantity = quantity
    
    @property
    def unique_id(self):
        """Gets the unique_id of this CompletionLineItem.

            The unique id identifies the line item on which the capture is applied on.

        :return: The unique_id of this CompletionLineItem.
        :rtype: str
        """
        return self._unique_id

    @unique_id.setter
    def unique_id(self, unique_id):
        """Sets the unique_id of this CompletionLineItem.

            The unique id identifies the line item on which the capture is applied on.

        :param unique_id: The unique_id of this CompletionLineItem.
        :type: str
        """
        if unique_id is not None and len(unique_id) > 200:
            raise ValueError("Invalid value for `unique_id`, length must be less than or equal to `200`")

        self._unique_id = unique_id
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(CompletionLineItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, CompletionLineItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class InvoiceReconciliationRecordInvoiceLink:

    swagger_types = {
    
        'amount': 'float',
        'created_on': 'datetime',
        'id': 'int',
        'invoice': 'TransactionInvoice',
        'linked_space_id': 'int',
        'record': 'InvoiceReconciliationRecord',
    }

    attribute_map = {
        'amount': 'amount','created_on': 'createdOn','id': 'id','invoice': 'invoice','linked_space_id': 'linkedSpaceId','record': 'record',
    }

    
    _amount = None
    _created_on = None
    _id = None
    _invoice = None
    _linked_space_id = None
    _record = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.amount = kwargs.get('amount', None)
        self.created_on = kwargs.get('created_on', None)
        self.id = kwargs.get('id', None)
        self.invoice = kwargs.get('invoice', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.record = kwargs.get('record', None)
        

    
    @property
    def amount(self):
        """Gets the amount of this InvoiceReconciliationRecordInvoiceLink.

            

        :return: The amount of this InvoiceReconciliationRecordInvoiceLink.
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this InvoiceReconciliationRecordInvoiceLink.

            

        :param amount: The amount of this InvoiceReconciliationRecordInvoiceLink.
        :type: float
        """

        self._amount = amount
    
    @property
    def created_on(self):
        """Gets the created_on of this InvoiceReconciliationRecordInvoiceLink.

            The created on date indicates the date on which the entity was stored into the database.

        :return: The created_on of this InvoiceReconciliationRecordInvoiceLink.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this InvoiceReconciliationRecordInvoiceLink.

            The created on date indicates the date on which the entity was stored into the database.

        :param created_on: The created_on of this InvoiceReconciliationRecordInvoiceLink.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def id(self):
        """Gets the id of this InvoiceReconciliationRecordInvoiceLink.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this InvoiceReconciliationRecordInvoiceLink.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InvoiceReconciliationRecordInvoiceLink.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this InvoiceReconciliationRecordInvoiceLink.
        :type: int
        """

        self._id = id
    
    @property
    def invoice(self):
        """Gets the invoice of this InvoiceReconciliationRecordInvoiceLink.

            

        :return: The invoice of this InvoiceReconciliationRecordInvoiceLink.
        :rtype: TransactionInvoice
        """
        return self._invoice

    @invoice.setter
    def invoice(self, invoice):
        """Sets the invoice of this InvoiceReconciliationRecordInvoiceLink.

            

        :param invoice: The invoice of this InvoiceReconciliationRecordInvoiceLink.
        :type: TransactionInvoice
        """

        self._invoice = invoice
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this InvoiceReconciliationRecordInvoiceLink.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this InvoiceReconciliationRecordInvoiceLink.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this InvoiceReconciliationRecordInvoiceLink.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this InvoiceReconciliationRecordInvoiceLink.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def record(self):
        """Gets the record of this InvoiceReconciliationRecordInvoiceLink.

            

        :return: The record of this InvoiceReconciliationRecordInvoiceLink.
        :rtype: InvoiceReconciliationRecord
        """
        return self._record

    @record.setter
    def record(self, record):
        """Sets the record of this InvoiceReconciliationRecordInvoiceLink.

            

        :param record: The record of this InvoiceReconciliationRecordInvoiceLink.
        :type: InvoiceReconciliationRecord
        """

        self._record = record
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(InvoiceReconciliationRecordInvoiceLink, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, InvoiceReconciliationRecordInvoiceLink):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from .account_service_api import AccountServiceApi
from .application_user_service_api import ApplicationUserServiceApi
from .bank_account_service_api import BankAccountServiceApi
from .bank_transaction_service_api import BankTransactionServiceApi
from .charge_attempt_service_api import ChargeAttemptServiceApi
from .charge_bank_transaction_service_api import ChargeBankTransactionServiceApi
from .charge_flow_level_payment_link_service_api import ChargeFlowLevelPaymentLinkServiceApi
from .charge_flow_level_service_api import ChargeFlowLevelServiceApi
from .charge_flow_service_api import ChargeFlowServiceApi
from .condition_type_service_api import ConditionTypeServiceApi
from .country_service_api import CountryServiceApi
from .country_state_service_api import CountryStateServiceApi
from .currency_bank_account_service_api import CurrencyBankAccountServiceApi
from .currency_service_api import CurrencyServiceApi
from .customer_address_service_api import CustomerAddressServiceApi
from .customer_comment_service_api import CustomerCommentServiceApi
from .customer_service_api import CustomerServiceApi
from .delivery_indication_service_api import DeliveryIndicationServiceApi
from .document_template_service_api import DocumentTemplateServiceApi
from .document_template_type_service_api import DocumentTemplateTypeServiceApi
from .external_transfer_bank_transaction_service_api import ExternalTransferBankTransactionServiceApi
from .human_user_service_api import HumanUserServiceApi
from .internal_transfer_bank_transaction_service_api import InternalTransferBankTransactionServiceApi
from .invoice_reconciliation_record_invoice_link_service_api import InvoiceReconciliationRecordInvoiceLinkServiceApi
from .invoice_reconciliation_record_service_api import InvoiceReconciliationRecordServiceApi
from .invoice_reimbursement_service_api import InvoiceReimbursementServiceApi
from .label_description_group_service_api import LabelDescriptionGroupServiceApi
from .label_description_service_api import LabelDescriptionServiceApi
from .language_service_api import LanguageServiceApi
from .legal_organization_form_service_api import LegalOrganizationFormServiceApi
from .manual_task_service_api import ManualTaskServiceApi
from .payment_connector_configuration_service_api import PaymentConnectorConfigurationServiceApi
from .payment_connector_service_api import PaymentConnectorServiceApi
from .payment_link_service_api import PaymentLinkServiceApi
from .payment_method_brand_service_api import PaymentMethodBrandServiceApi
from .payment_method_configuration_service_api import PaymentMethodConfigurationServiceApi
from .payment_method_service_api import PaymentMethodServiceApi
from .payment_processor_configuration_service_api import PaymentProcessorConfigurationServiceApi
from .payment_processor_service_api import PaymentProcessorServiceApi
from .payment_terminal_service_api import PaymentTerminalServiceApi
from .payment_terminal_till_service_api import PaymentTerminalTillServiceApi
from .payment_terminal_transaction_summary_service_api import PaymentTerminalTransactionSummaryServiceApi
from .permission_service_api import PermissionServiceApi
from .refund_bank_transaction_service_api import RefundBankTransactionServiceApi
from .refund_comment_service_api import RefundCommentServiceApi
from .refund_recovery_bank_transaction_service_api import RefundRecoveryBankTransactionServiceApi
from .refund_service_api import RefundServiceApi
from .shopify_recurring_order_service_api import ShopifyRecurringOrderServiceApi
from .shopify_subscriber_service_api import ShopifySubscriberServiceApi
from .shopify_subscription_product_service_api import ShopifySubscriptionProductServiceApi
from .shopify_subscription_service_api import ShopifySubscriptionServiceApi
from .shopify_subscription_suspension_service_api import ShopifySubscriptionSuspensionServiceApi
from .shopify_subscription_version_service_api import ShopifySubscriptionVersionServiceApi
from .shopify_transaction_service_api import ShopifyTransactionServiceApi
from .space_service_api import SpaceServiceApi
from .static_value_service_api import StaticValueServiceApi
from .token_service_api import TokenServiceApi
from .token_version_service_api import TokenVersionServiceApi
from .transaction_comment_service_api import TransactionCommentServiceApi
from .transaction_completion_service_api import TransactionCompletionServiceApi
from .transaction_iframe_service_api import TransactionIframeServiceApi
from .transaction_invoice_comment_service_api import TransactionInvoiceCommentServiceApi
from .transaction_invoice_service_api import TransactionInvoiceServiceApi
from .transaction_lightbox_service_api import TransactionLightboxServiceApi
from .transaction_line_item_version_service_api import TransactionLineItemVersionServiceApi
from .transaction_mobile_sdk_service_api import TransactionMobileSdkServiceApi
from .transaction_payment_page_service_api import TransactionPaymentPageServiceApi
from .transaction_service_api import TransactionServiceApi
from .transaction_terminal_service_api import TransactionTerminalServiceApi
from .transaction_void_service_api import TransactionVoidServiceApi
from .user_account_role_service_api import UserAccountRoleServiceApi
from .user_space_role_service_api import UserSpaceRoleServiceApi
from .webhook_listener_service_api import WebhookListenerServiceApi
from .webhook_url_service_api import WebhookUrlServiceApi



# coding: utf-8
import pprint
import six
from enum import Enum



class ManualTask:

    swagger_types = {
    
        'actions': 'list[int]',
        'context_entity_id': 'int',
        'created_on': 'datetime',
        'expires_on': 'datetime',
        'id': 'int',
        'linked_space_id': 'int',
        'planned_purge_date': 'datetime',
        'space_id': 'int',
        'state': 'ManualTaskState',
        'type': 'int',
    }

    attribute_map = {
        'actions': 'actions','context_entity_id': 'contextEntityId','created_on': 'createdOn','expires_on': 'expiresOn','id': 'id','linked_space_id': 'linkedSpaceId','planned_purge_date': 'plannedPurgeDate','space_id': 'spaceId','state': 'state','type': 'type',
    }

    
    _actions = None
    _context_entity_id = None
    _created_on = None
    _expires_on = None
    _id = None
    _linked_space_id = None
    _planned_purge_date = None
    _space_id = None
    _state = None
    _type = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.actions = kwargs.get('actions', None)
        self.context_entity_id = kwargs.get('context_entity_id', None)
        self.created_on = kwargs.get('created_on', None)
        self.expires_on = kwargs.get('expires_on', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.space_id = kwargs.get('space_id', None)
        self.state = kwargs.get('state', None)
        self.type = kwargs.get('type', None)
        

    
    @property
    def actions(self):
        """Gets the actions of this ManualTask.

            

        :return: The actions of this ManualTask.
        :rtype: list[int]
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """Sets the actions of this ManualTask.

            

        :param actions: The actions of this ManualTask.
        :type: list[int]
        """

        self._actions = actions
    
    @property
    def context_entity_id(self):
        """Gets the context_entity_id of this ManualTask.

            The context entity ID links the manual task to the entity which caused its creation.

        :return: The context_entity_id of this ManualTask.
        :rtype: int
        """
        return self._context_entity_id

    @context_entity_id.setter
    def context_entity_id(self, context_entity_id):
        """Sets the context_entity_id of this ManualTask.

            The context entity ID links the manual task to the entity which caused its creation.

        :param context_entity_id: The context_entity_id of this ManualTask.
        :type: int
        """

        self._context_entity_id = context_entity_id
    
    @property
    def created_on(self):
        """Gets the created_on of this ManualTask.

            The created on date indicates the date on which the entity was stored into the database.

        :return: The created_on of this ManualTask.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this ManualTask.

            The created on date indicates the date on which the entity was stored into the database.

        :param created_on: The created_on of this ManualTask.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def expires_on(self):
        """Gets the expires_on of this ManualTask.

            The expiry date indicates until when the manual task has to be executed.

        :return: The expires_on of this ManualTask.
        :rtype: datetime
        """
        return self._expires_on

    @expires_on.setter
    def expires_on(self, expires_on):
        """Sets the expires_on of this ManualTask.

            The expiry date indicates until when the manual task has to be executed.

        :param expires_on: The expires_on of this ManualTask.
        :type: datetime
        """

        self._expires_on = expires_on
    
    @property
    def id(self):
        """Gets the id of this ManualTask.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this ManualTask.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ManualTask.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this ManualTask.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this ManualTask.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this ManualTask.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this ManualTask.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this ManualTask.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this ManualTask.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this ManualTask.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this ManualTask.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this ManualTask.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def space_id(self):
        """Gets the space_id of this ManualTask.

            

        :return: The space_id of this ManualTask.
        :rtype: int
        """
        return self._space_id

    @space_id.setter
    def space_id(self, space_id):
        """Sets the space_id of this ManualTask.

            

        :param space_id: The space_id of this ManualTask.
        :type: int
        """

        self._space_id = space_id
    
    @property
    def state(self):
        """Gets the state of this ManualTask.

            

        :return: The state of this ManualTask.
        :rtype: ManualTaskState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ManualTask.

            

        :param state: The state of this ManualTask.
        :type: ManualTaskState
        """

        self._state = state
    
    @property
    def type(self):
        """Gets the type of this ManualTask.

            The type categorizes the manual task.

        :return: The type of this ManualTask.
        :rtype: int
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ManualTask.

            The type categorizes the manual task.

        :param type: The type of this ManualTask.
        :type: int
        """

        self._type = type
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ManualTask, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ManualTask):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from postfinancecheckout.api.account_service_api import AccountServiceApi
from postfinancecheckout.api.application_user_service_api import ApplicationUserServiceApi
from postfinancecheckout.api.bank_account_service_api import BankAccountServiceApi
from postfinancecheckout.api.bank_transaction_service_api import BankTransactionServiceApi
from postfinancecheckout.api.charge_attempt_service_api import ChargeAttemptServiceApi
from postfinancecheckout.api.charge_bank_transaction_service_api import ChargeBankTransactionServiceApi
from postfinancecheckout.api.charge_flow_level_payment_link_service_api import ChargeFlowLevelPaymentLinkServiceApi
from postfinancecheckout.api.charge_flow_level_service_api import ChargeFlowLevelServiceApi
from postfinancecheckout.api.charge_flow_service_api import ChargeFlowServiceApi
from postfinancecheckout.api.condition_type_service_api import ConditionTypeServiceApi
from postfinancecheckout.api.country_service_api import CountryServiceApi
from postfinancecheckout.api.country_state_service_api import CountryStateServiceApi
from postfinancecheckout.api.currency_bank_account_service_api import CurrencyBankAccountServiceApi
from postfinancecheckout.api.currency_service_api import CurrencyServiceApi
from postfinancecheckout.api.customer_address_service_api import CustomerAddressServiceApi
from postfinancecheckout.api.customer_comment_service_api import CustomerCommentServiceApi
from postfinancecheckout.api.customer_service_api import CustomerServiceApi
from postfinancecheckout.api.delivery_indication_service_api import DeliveryIndicationServiceApi
from postfinancecheckout.api.document_template_service_api import DocumentTemplateServiceApi
from postfinancecheckout.api.document_template_type_service_api import DocumentTemplateTypeServiceApi
from postfinancecheckout.api.external_transfer_bank_transaction_service_api import ExternalTransferBankTransactionServiceApi
from postfinancecheckout.api.human_user_service_api import HumanUserServiceApi
from postfinancecheckout.api.internal_transfer_bank_transaction_service_api import InternalTransferBankTransactionServiceApi
from postfinancecheckout.api.invoice_reconciliation_record_invoice_link_service_api import InvoiceReconciliationRecordInvoiceLinkServiceApi
from postfinancecheckout.api.invoice_reconciliation_record_service_api import InvoiceReconciliationRecordServiceApi
from postfinancecheckout.api.invoice_reimbursement_service_api import InvoiceReimbursementServiceApi
from postfinancecheckout.api.label_description_group_service_api import LabelDescriptionGroupServiceApi
from postfinancecheckout.api.label_description_service_api import LabelDescriptionServiceApi
from postfinancecheckout.api.language_service_api import LanguageServiceApi
from postfinancecheckout.api.legal_organization_form_service_api import LegalOrganizationFormServiceApi
from postfinancecheckout.api.manual_task_service_api import ManualTaskServiceApi
from postfinancecheckout.api.payment_connector_configuration_service_api import PaymentConnectorConfigurationServiceApi
from postfinancecheckout.api.payment_connector_service_api import PaymentConnectorServiceApi
from postfinancecheckout.api.payment_link_service_api import PaymentLinkServiceApi
from postfinancecheckout.api.payment_method_brand_service_api import PaymentMethodBrandServiceApi
from postfinancecheckout.api.payment_method_configuration_service_api import PaymentMethodConfigurationServiceApi
from postfinancecheckout.api.payment_method_service_api import PaymentMethodServiceApi
from postfinancecheckout.api.payment_processor_configuration_service_api import PaymentProcessorConfigurationServiceApi
from postfinancecheckout.api.payment_processor_service_api import PaymentProcessorServiceApi
from postfinancecheckout.api.payment_terminal_service_api import PaymentTerminalServiceApi
from postfinancecheckout.api.payment_terminal_till_service_api import PaymentTerminalTillServiceApi
from postfinancecheckout.api.payment_terminal_transaction_summary_service_api import PaymentTerminalTransactionSummaryServiceApi
from postfinancecheckout.api.permission_service_api import PermissionServiceApi
from postfinancecheckout.api.refund_bank_transaction_service_api import RefundBankTransactionServiceApi
from postfinancecheckout.api.refund_comment_service_api import RefundCommentServiceApi
from postfinancecheckout.api.refund_recovery_bank_transaction_service_api import RefundRecoveryBankTransactionServiceApi
from postfinancecheckout.api.refund_service_api import RefundServiceApi
from postfinancecheckout.api.shopify_recurring_order_service_api import ShopifyRecurringOrderServiceApi
from postfinancecheckout.api.shopify_subscriber_service_api import ShopifySubscriberServiceApi
from postfinancecheckout.api.shopify_subscription_product_service_api import ShopifySubscriptionProductServiceApi
from postfinancecheckout.api.shopify_subscription_service_api import ShopifySubscriptionServiceApi
from postfinancecheckout.api.shopify_subscription_suspension_service_api import ShopifySubscriptionSuspensionServiceApi
from postfinancecheckout.api.shopify_subscription_version_service_api import ShopifySubscriptionVersionServiceApi
from postfinancecheckout.api.shopify_transaction_service_api import ShopifyTransactionServiceApi
from postfinancecheckout.api.space_service_api import SpaceServiceApi
from postfinancecheckout.api.static_value_service_api import StaticValueServiceApi
from postfinancecheckout.api.token_service_api import TokenServiceApi
from postfinancecheckout.api.token_version_service_api import TokenVersionServiceApi
from postfinancecheckout.api.transaction_comment_service_api import TransactionCommentServiceApi
from postfinancecheckout.api.transaction_completion_service_api import TransactionCompletionServiceApi
from postfinancecheckout.api.transaction_iframe_service_api import TransactionIframeServiceApi
from postfinancecheckout.api.transaction_invoice_comment_service_api import TransactionInvoiceCommentServiceApi
from postfinancecheckout.api.transaction_invoice_service_api import TransactionInvoiceServiceApi
from postfinancecheckout.api.transaction_lightbox_service_api import TransactionLightboxServiceApi
from postfinancecheckout.api.transaction_line_item_version_service_api import TransactionLineItemVersionServiceApi
from postfinancecheckout.api.transaction_mobile_sdk_service_api import TransactionMobileSdkServiceApi
from postfinancecheckout.api.transaction_payment_page_service_api import TransactionPaymentPageServiceApi
from postfinancecheckout.api.transaction_service_api import TransactionServiceApi
from postfinancecheckout.api.transaction_terminal_service_api import TransactionTerminalServiceApi
from postfinancecheckout.api.transaction_void_service_api import TransactionVoidServiceApi
from postfinancecheckout.api.user_account_role_service_api import UserAccountRoleServiceApi
from postfinancecheckout.api.user_space_role_service_api import UserSpaceRoleServiceApi
from postfinancecheckout.api.webhook_listener_service_api import WebhookListenerServiceApi
from postfinancecheckout.api.webhook_url_service_api import WebhookUrlServiceApi


from postfinancecheckout.api_client import ApiClient
from postfinancecheckout.configuration import Configuration

from postfinancecheckout.models.abstract_account_update import AbstractAccountUpdate
from postfinancecheckout.models.abstract_application_user_update import AbstractApplicationUserUpdate
from postfinancecheckout.models.abstract_customer_active import AbstractCustomerActive
from postfinancecheckout.models.abstract_customer_address_active import AbstractCustomerAddressActive
from postfinancecheckout.models.abstract_customer_comment_active import AbstractCustomerCommentActive
from postfinancecheckout.models.abstract_human_user_update import AbstractHumanUserUpdate
from postfinancecheckout.models.abstract_payment_link_update import AbstractPaymentLinkUpdate
from postfinancecheckout.models.abstract_refund_comment_active import AbstractRefundCommentActive
from postfinancecheckout.models.abstract_shopify_subscription_product_update import AbstractShopifySubscriptionProductUpdate
from postfinancecheckout.models.abstract_space_update import AbstractSpaceUpdate
from postfinancecheckout.models.abstract_token_update import AbstractTokenUpdate
from postfinancecheckout.models.abstract_transaction_comment_active import AbstractTransactionCommentActive
from postfinancecheckout.models.abstract_transaction_invoice_comment_active import AbstractTransactionInvoiceCommentActive
from postfinancecheckout.models.abstract_transaction_pending import AbstractTransactionPending
from postfinancecheckout.models.abstract_webhook_listener_update import AbstractWebhookListenerUpdate
from postfinancecheckout.models.abstract_webhook_url_update import AbstractWebhookUrlUpdate
from postfinancecheckout.models.account import Account
from postfinancecheckout.models.account_state import AccountState
from postfinancecheckout.models.account_type import AccountType
from postfinancecheckout.models.address import Address
from postfinancecheckout.models.address_create import AddressCreate
from postfinancecheckout.models.bank_account import BankAccount
from postfinancecheckout.models.bank_account_environment import BankAccountEnvironment
from postfinancecheckout.models.bank_account_state import BankAccountState
from postfinancecheckout.models.bank_account_type import BankAccountType
from postfinancecheckout.models.bank_transaction import BankTransaction
from postfinancecheckout.models.bank_transaction_flow_direction import BankTransactionFlowDirection
from postfinancecheckout.models.bank_transaction_source import BankTransactionSource
from postfinancecheckout.models.bank_transaction_state import BankTransactionState
from postfinancecheckout.models.bank_transaction_type import BankTransactionType
from postfinancecheckout.models.charge_attempt_environment import ChargeAttemptEnvironment
from postfinancecheckout.models.charge_attempt_state import ChargeAttemptState
from postfinancecheckout.models.charge_flow import ChargeFlow
from postfinancecheckout.models.charge_flow_level_configuration import ChargeFlowLevelConfiguration
from postfinancecheckout.models.charge_flow_level_configuration_type import ChargeFlowLevelConfigurationType
from postfinancecheckout.models.charge_flow_level_state import ChargeFlowLevelState
from postfinancecheckout.models.charge_state import ChargeState
from postfinancecheckout.models.charge_type import ChargeType
from postfinancecheckout.models.client_error import ClientError
from postfinancecheckout.models.client_error_type import ClientErrorType
from postfinancecheckout.models.completion_line_item import CompletionLineItem
from postfinancecheckout.models.completion_line_item_create import CompletionLineItemCreate
from postfinancecheckout.models.condition import Condition
from postfinancecheckout.models.condition_type import ConditionType
from postfinancecheckout.models.connector_invocation_stage import ConnectorInvocationStage
from postfinancecheckout.models.creation_entity_state import CreationEntityState
from postfinancecheckout.models.criteria_operator import CriteriaOperator
from postfinancecheckout.models.currency_bank_account import CurrencyBankAccount
from postfinancecheckout.models.customer import Customer
from postfinancecheckout.models.customer_address import CustomerAddress
from postfinancecheckout.models.customer_address_type import CustomerAddressType
from postfinancecheckout.models.customer_comment import CustomerComment
from postfinancecheckout.models.customer_postal_address import CustomerPostalAddress
from postfinancecheckout.models.customer_postal_address_create import CustomerPostalAddressCreate
from postfinancecheckout.models.customers_presence import CustomersPresence
from postfinancecheckout.models.data_collection_type import DataCollectionType
from postfinancecheckout.models.database_translated_string import DatabaseTranslatedString
from postfinancecheckout.models.database_translated_string_item import DatabaseTranslatedStringItem
from postfinancecheckout.models.delivery_indication_decision_reason import DeliveryIndicationDecisionReason
from postfinancecheckout.models.delivery_indication_state import DeliveryIndicationState
from postfinancecheckout.models.document_template import DocumentTemplate
from postfinancecheckout.models.document_template_type import DocumentTemplateType
from postfinancecheckout.models.document_template_type_group import DocumentTemplateTypeGroup
from postfinancecheckout.models.entity_export_request import EntityExportRequest
from postfinancecheckout.models.entity_query import EntityQuery
from postfinancecheckout.models.entity_query_filter import EntityQueryFilter
from postfinancecheckout.models.entity_query_filter_type import EntityQueryFilterType
from postfinancecheckout.models.entity_query_order_by import EntityQueryOrderBy
from postfinancecheckout.models.entity_query_order_by_type import EntityQueryOrderByType
from postfinancecheckout.models.environment import Environment
from postfinancecheckout.models.external_transfer_bank_transaction import ExternalTransferBankTransaction
from postfinancecheckout.models.failure_category import FailureCategory
from postfinancecheckout.models.failure_reason import FailureReason
from postfinancecheckout.models.feature import Feature
from postfinancecheckout.models.feature_category import FeatureCategory
from postfinancecheckout.models.gender import Gender
from postfinancecheckout.models.human_user import HumanUser
from postfinancecheckout.models.internal_transfer_bank_transaction import InternalTransferBankTransaction
from postfinancecheckout.models.invoice_reconciliation_record_invoice_link import InvoiceReconciliationRecordInvoiceLink
from postfinancecheckout.models.invoice_reconciliation_record_rejection_status import InvoiceReconciliationRecordRejectionStatus
from postfinancecheckout.models.invoice_reconciliation_record_state import InvoiceReconciliationRecordState
from postfinancecheckout.models.invoice_reconciliation_record_type import InvoiceReconciliationRecordType
from postfinancecheckout.models.invoice_reimbursement import InvoiceReimbursement
from postfinancecheckout.models.invoice_reimbursement_state import InvoiceReimbursementState
from postfinancecheckout.models.label import Label
from postfinancecheckout.models.label_descriptor import LabelDescriptor
from postfinancecheckout.models.label_descriptor_category import LabelDescriptorCategory
from postfinancecheckout.models.label_descriptor_group import LabelDescriptorGroup
from postfinancecheckout.models.label_descriptor_type import LabelDescriptorType
from postfinancecheckout.models.legal_organization_form import LegalOrganizationForm
from postfinancecheckout.models.line_item import LineItem
from postfinancecheckout.models.line_item_attribute import LineItemAttribute
from postfinancecheckout.models.line_item_attribute_create import LineItemAttributeCreate
from postfinancecheckout.models.line_item_create import LineItemCreate
from postfinancecheckout.models.line_item_reduction import LineItemReduction
from postfinancecheckout.models.line_item_reduction_create import LineItemReductionCreate
from postfinancecheckout.models.line_item_type import LineItemType
from postfinancecheckout.models.localized_string import LocalizedString
from postfinancecheckout.models.manual_task import ManualTask
from postfinancecheckout.models.manual_task_action import ManualTaskAction
from postfinancecheckout.models.manual_task_action_style import ManualTaskActionStyle
from postfinancecheckout.models.manual_task_state import ManualTaskState
from postfinancecheckout.models.manual_task_type import ManualTaskType
from postfinancecheckout.models.one_click_payment_mode import OneClickPaymentMode
from postfinancecheckout.models.payment_adjustment import PaymentAdjustment
from postfinancecheckout.models.payment_adjustment_type import PaymentAdjustmentType
from postfinancecheckout.models.payment_connector import PaymentConnector
from postfinancecheckout.models.payment_connector_configuration import PaymentConnectorConfiguration
from postfinancecheckout.models.payment_connector_feature import PaymentConnectorFeature
from postfinancecheckout.models.payment_contract import PaymentContract
from postfinancecheckout.models.payment_contract_state import PaymentContractState
from postfinancecheckout.models.payment_contract_type import PaymentContractType
from postfinancecheckout.models.payment_information_hash import PaymentInformationHash
from postfinancecheckout.models.payment_information_hash_type import PaymentInformationHashType
from postfinancecheckout.models.payment_initiation_advice_file import PaymentInitiationAdviceFile
from postfinancecheckout.models.payment_initiation_advice_file_state import PaymentInitiationAdviceFileState
from postfinancecheckout.models.payment_link import PaymentLink
from postfinancecheckout.models.payment_link_address_handling_mode import PaymentLinkAddressHandlingMode
from postfinancecheckout.models.payment_link_protection_mode import PaymentLinkProtectionMode
from postfinancecheckout.models.payment_link_update import PaymentLinkUpdate
from postfinancecheckout.models.payment_method import PaymentMethod
from postfinancecheckout.models.payment_method_brand import PaymentMethodBrand
from postfinancecheckout.models.payment_method_configuration import PaymentMethodConfiguration
from postfinancecheckout.models.payment_primary_risk_taker import PaymentPrimaryRiskTaker
from postfinancecheckout.models.payment_processor import PaymentProcessor
from postfinancecheckout.models.payment_processor_configuration import PaymentProcessorConfiguration
from postfinancecheckout.models.payment_terminal import PaymentTerminal
from postfinancecheckout.models.payment_terminal_address import PaymentTerminalAddress
from postfinancecheckout.models.payment_terminal_configuration import PaymentTerminalConfiguration
from postfinancecheckout.models.payment_terminal_configuration_state import PaymentTerminalConfigurationState
from postfinancecheckout.models.payment_terminal_configuration_version import PaymentTerminalConfigurationVersion
from postfinancecheckout.models.payment_terminal_configuration_version_state import PaymentTerminalConfigurationVersionState
from postfinancecheckout.models.payment_terminal_dcc_transaction_sum import PaymentTerminalDccTransactionSum
from postfinancecheckout.models.payment_terminal_location import PaymentTerminalLocation
from postfinancecheckout.models.payment_terminal_location_state import PaymentTerminalLocationState
from postfinancecheckout.models.payment_terminal_location_version import PaymentTerminalLocationVersion
from postfinancecheckout.models.payment_terminal_location_version_state import PaymentTerminalLocationVersionState
from postfinancecheckout.models.payment_terminal_receipt_type import PaymentTerminalReceiptType
from postfinancecheckout.models.payment_terminal_state import PaymentTerminalState
from postfinancecheckout.models.payment_terminal_transaction_sum import PaymentTerminalTransactionSum
from postfinancecheckout.models.payment_terminal_transaction_summary import PaymentTerminalTransactionSummary
from postfinancecheckout.models.payment_terminal_transaction_summary_fetch_request import PaymentTerminalTransactionSummaryFetchRequest
from postfinancecheckout.models.payment_terminal_type import PaymentTerminalType
from postfinancecheckout.models.permission import Permission
from postfinancecheckout.models.refund import Refund
from postfinancecheckout.models.refund_comment import RefundComment
from postfinancecheckout.models.refund_create import RefundCreate
from postfinancecheckout.models.refund_state import RefundState
from postfinancecheckout.models.refund_type import RefundType
from postfinancecheckout.models.rendered_document import RenderedDocument
from postfinancecheckout.models.rendered_terminal_receipt import RenderedTerminalReceipt
from postfinancecheckout.models.rendered_terminal_transaction_summary import RenderedTerminalTransactionSummary
from postfinancecheckout.models.resource_path import ResourcePath
from postfinancecheckout.models.resource_state import ResourceState
from postfinancecheckout.models.rest_address_format import RestAddressFormat
from postfinancecheckout.models.rest_address_format_field import RestAddressFormatField
from postfinancecheckout.models.rest_country import RestCountry
from postfinancecheckout.models.rest_country_state import RestCountryState
from postfinancecheckout.models.rest_currency import RestCurrency
from postfinancecheckout.models.rest_language import RestLanguage
from postfinancecheckout.models.role import Role
from postfinancecheckout.models.role_state import RoleState
from postfinancecheckout.models.sales_channel import SalesChannel
from postfinancecheckout.models.scope import Scope
from postfinancecheckout.models.server_error import ServerError
from postfinancecheckout.models.shopify_additional_line_item_data import ShopifyAdditionalLineItemData
from postfinancecheckout.models.shopify_integration import ShopifyIntegration
from postfinancecheckout.models.shopify_integration_payment_app_version import ShopifyIntegrationPaymentAppVersion
from postfinancecheckout.models.shopify_integration_subscription_app_version import ShopifyIntegrationSubscriptionAppVersion
from postfinancecheckout.models.shopify_recurring_order_state import ShopifyRecurringOrderState
from postfinancecheckout.models.shopify_recurring_order_update_request import ShopifyRecurringOrderUpdateRequest
from postfinancecheckout.models.shopify_subscriber import ShopifySubscriber
from postfinancecheckout.models.shopify_subscriber_active import ShopifySubscriberActive
from postfinancecheckout.models.shopify_subscriber_creation import ShopifySubscriberCreation
from postfinancecheckout.models.shopify_subscriber_state import ShopifySubscriberState
from postfinancecheckout.models.shopify_subscription import ShopifySubscription
from postfinancecheckout.models.shopify_subscription_address_create import ShopifySubscriptionAddressCreate
from postfinancecheckout.models.shopify_subscription_billing_interval_unit import ShopifySubscriptionBillingIntervalUnit
from postfinancecheckout.models.shopify_subscription_creation_request import ShopifySubscriptionCreationRequest
from postfinancecheckout.models.shopify_subscription_model_billing_configuration import ShopifySubscriptionModelBillingConfiguration
from postfinancecheckout.models.shopify_subscription_model_item import ShopifySubscriptionModelItem
from postfinancecheckout.models.shopify_subscription_model_tax_line import ShopifySubscriptionModelTaxLine
from postfinancecheckout.models.shopify_subscription_product import ShopifySubscriptionProduct
from postfinancecheckout.models.shopify_subscription_product_pricing_option import ShopifySubscriptionProductPricingOption
from postfinancecheckout.models.shopify_subscription_product_state import ShopifySubscriptionProductState
from postfinancecheckout.models.shopify_subscription_state import ShopifySubscriptionState
from postfinancecheckout.models.shopify_subscription_suspension import ShopifySubscriptionSuspension
from postfinancecheckout.models.shopify_subscription_suspension_create import ShopifySubscriptionSuspensionCreate
from postfinancecheckout.models.shopify_subscription_suspension_initiator import ShopifySubscriptionSuspensionInitiator
from postfinancecheckout.models.shopify_subscription_suspension_state import ShopifySubscriptionSuspensionState
from postfinancecheckout.models.shopify_subscription_suspension_type import ShopifySubscriptionSuspensionType
from postfinancecheckout.models.shopify_subscription_update_addresses_request import ShopifySubscriptionUpdateAddressesRequest
from postfinancecheckout.models.shopify_subscription_update_request import ShopifySubscriptionUpdateRequest
from postfinancecheckout.models.shopify_subscription_version import ShopifySubscriptionVersion
from postfinancecheckout.models.shopify_subscription_version_item import ShopifySubscriptionVersionItem
from postfinancecheckout.models.shopify_subscription_version_item_price_strategy import ShopifySubscriptionVersionItemPriceStrategy
from postfinancecheckout.models.shopify_subscription_version_state import ShopifySubscriptionVersionState
from postfinancecheckout.models.shopify_subscription_weekday import ShopifySubscriptionWeekday
from postfinancecheckout.models.shopify_tax_line import ShopifyTaxLine
from postfinancecheckout.models.shopify_transaction_state import ShopifyTransactionState
from postfinancecheckout.models.space import Space
from postfinancecheckout.models.space_address import SpaceAddress
from postfinancecheckout.models.space_address_create import SpaceAddressCreate
from postfinancecheckout.models.space_view import SpaceView
from postfinancecheckout.models.static_value import StaticValue
from postfinancecheckout.models.tax import Tax
from postfinancecheckout.models.tax_create import TaxCreate
from postfinancecheckout.models.tenant_database import TenantDatabase
from postfinancecheckout.models.terminal_receipt_fetch_request import TerminalReceiptFetchRequest
from postfinancecheckout.models.terminal_receipt_format import TerminalReceiptFormat
from postfinancecheckout.models.token import Token
from postfinancecheckout.models.token_version import TokenVersion
from postfinancecheckout.models.token_version_state import TokenVersionState
from postfinancecheckout.models.token_version_type import TokenVersionType
from postfinancecheckout.models.tokenization_mode import TokenizationMode
from postfinancecheckout.models.transaction import Transaction
from postfinancecheckout.models.transaction_aware_entity import TransactionAwareEntity
from postfinancecheckout.models.transaction_comment import TransactionComment
from postfinancecheckout.models.transaction_completion_behavior import TransactionCompletionBehavior
from postfinancecheckout.models.transaction_completion_mode import TransactionCompletionMode
from postfinancecheckout.models.transaction_completion_request import TransactionCompletionRequest
from postfinancecheckout.models.transaction_completion_state import TransactionCompletionState
from postfinancecheckout.models.transaction_environment_selection_strategy import TransactionEnvironmentSelectionStrategy
from postfinancecheckout.models.transaction_group import TransactionGroup
from postfinancecheckout.models.transaction_group_state import TransactionGroupState
from postfinancecheckout.models.transaction_invoice_comment import TransactionInvoiceComment
from postfinancecheckout.models.transaction_invoice_replacement import TransactionInvoiceReplacement
from postfinancecheckout.models.transaction_invoice_state import TransactionInvoiceState
from postfinancecheckout.models.transaction_line_item_version_create import TransactionLineItemVersionCreate
from postfinancecheckout.models.transaction_line_item_version_state import TransactionLineItemVersionState
from postfinancecheckout.models.transaction_state import TransactionState
from postfinancecheckout.models.transaction_user_interface_type import TransactionUserInterfaceType
from postfinancecheckout.models.transaction_void_mode import TransactionVoidMode
from postfinancecheckout.models.transaction_void_state import TransactionVoidState
from postfinancecheckout.models.two_factor_authentication_type import TwoFactorAuthenticationType
from postfinancecheckout.models.user import User
from postfinancecheckout.models.user_account_role import UserAccountRole
from postfinancecheckout.models.user_space_role import UserSpaceRole
from postfinancecheckout.models.user_type import UserType
from postfinancecheckout.models.webhook_identity import WebhookIdentity
from postfinancecheckout.models.webhook_listener import WebhookListener
from postfinancecheckout.models.webhook_listener_entity import WebhookListenerEntity
from postfinancecheckout.models.webhook_url import WebhookUrl
from postfinancecheckout.models.account_create import AccountCreate
from postfinancecheckout.models.account_update import AccountUpdate
from postfinancecheckout.models.application_user import ApplicationUser
from postfinancecheckout.models.application_user_create import ApplicationUserCreate
from postfinancecheckout.models.application_user_update import ApplicationUserUpdate
from postfinancecheckout.models.charge import Charge
from postfinancecheckout.models.charge_attempt import ChargeAttempt
from postfinancecheckout.models.charge_bank_transaction import ChargeBankTransaction
from postfinancecheckout.models.charge_flow_level import ChargeFlowLevel
from postfinancecheckout.models.charge_flow_level_payment_link import ChargeFlowLevelPaymentLink
from postfinancecheckout.models.connector_invocation import ConnectorInvocation
from postfinancecheckout.models.customer_active import CustomerActive
from postfinancecheckout.models.customer_address_active import CustomerAddressActive
from postfinancecheckout.models.customer_address_create import CustomerAddressCreate
from postfinancecheckout.models.customer_comment_active import CustomerCommentActive
from postfinancecheckout.models.customer_comment_create import CustomerCommentCreate
from postfinancecheckout.models.customer_create import CustomerCreate
from postfinancecheckout.models.delivery_indication import DeliveryIndication
from postfinancecheckout.models.human_user_create import HumanUserCreate
from postfinancecheckout.models.human_user_update import HumanUserUpdate
from postfinancecheckout.models.invoice_reconciliation_record import InvoiceReconciliationRecord
from postfinancecheckout.models.invoice_reimbursement_with_refund_reference import InvoiceReimbursementWithRefundReference
from postfinancecheckout.models.payment_link_active import PaymentLinkActive
from postfinancecheckout.models.payment_link_create import PaymentLinkCreate
from postfinancecheckout.models.refund_bank_transaction import RefundBankTransaction
from postfinancecheckout.models.refund_comment_active import RefundCommentActive
from postfinancecheckout.models.refund_comment_create import RefundCommentCreate
from postfinancecheckout.models.refund_recovery_bank_transaction import RefundRecoveryBankTransaction
from postfinancecheckout.models.shopify_recurring_order import ShopifyRecurringOrder
from postfinancecheckout.models.shopify_subscription_address import ShopifySubscriptionAddress
from postfinancecheckout.models.shopify_subscription_product_create import ShopifySubscriptionProductCreate
from postfinancecheckout.models.shopify_subscription_product_update import ShopifySubscriptionProductUpdate
from postfinancecheckout.models.shopify_transaction import ShopifyTransaction
from postfinancecheckout.models.space_create import SpaceCreate
from postfinancecheckout.models.space_update import SpaceUpdate
from postfinancecheckout.models.token_create import TokenCreate
from postfinancecheckout.models.token_update import TokenUpdate
from postfinancecheckout.models.transaction_comment_active import TransactionCommentActive
from postfinancecheckout.models.transaction_comment_create import TransactionCommentCreate
from postfinancecheckout.models.transaction_completion import TransactionCompletion
from postfinancecheckout.models.transaction_create import TransactionCreate
from postfinancecheckout.models.transaction_invoice import TransactionInvoice
from postfinancecheckout.models.transaction_invoice_comment_active import TransactionInvoiceCommentActive
from postfinancecheckout.models.transaction_invoice_comment_create import TransactionInvoiceCommentCreate
from postfinancecheckout.models.transaction_line_item_version import TransactionLineItemVersion
from postfinancecheckout.models.transaction_pending import TransactionPending
from postfinancecheckout.models.transaction_void import TransactionVoid
from postfinancecheckout.models.webhook_listener_create import WebhookListenerCreate
from postfinancecheckout.models.webhook_listener_update import WebhookListenerUpdate
from postfinancecheckout.models.webhook_url_create import WebhookUrlCreate
from postfinancecheckout.models.webhook_url_update import WebhookUrlUpdate
from postfinancecheckout.models.application_user_create_with_mac_key import ApplicationUserCreateWithMacKey



# coding: utf-8
import pprint
import six
from enum import Enum



class EntityExportRequest:

    swagger_types = {
    
        'properties': 'list[str]',
        'query': 'EntityQuery',
    }

    attribute_map = {
        'properties': 'properties','query': 'query',
    }

    
    _properties = None
    _query = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.properties = kwargs.get('properties')

        self.query = kwargs.get('query', None)
        

    
    @property
    def properties(self):
        """Gets the properties of this EntityExportRequest.

            The properties is a list of property paths which should be exported.

        :return: The properties of this EntityExportRequest.
        :rtype: list[str]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this EntityExportRequest.

            The properties is a list of property paths which should be exported.

        :param properties: The properties of this EntityExportRequest.
        :type: list[str]
        """
        if properties is None:
            raise ValueError("Invalid value for `properties`, must not be `None`")

        self._properties = properties
    
    @property
    def query(self):
        """Gets the query of this EntityExportRequest.

            The query limits the returned entries. The query allows to restrict the entries to return and it allows to control the order of them.

        :return: The query of this EntityExportRequest.
        :rtype: EntityQuery
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this EntityExportRequest.

            The query limits the returned entries. The query allows to restrict the entries to return and it allows to control the order of them.

        :param query: The query of this EntityExportRequest.
        :type: EntityQuery
        """

        self._query = query
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(EntityExportRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, EntityExportRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractApplicationUserUpdate:

    swagger_types = {
    
        'name': 'str',
        'request_limit': 'int',
        'state': 'CreationEntityState',
    }

    attribute_map = {
        'name': 'name','request_limit': 'requestLimit','state': 'state',
    }

    
    _name = None
    _request_limit = None
    _state = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.name = kwargs.get('name', None)
        self.request_limit = kwargs.get('request_limit', None)
        self.state = kwargs.get('state', None)
        

    
    @property
    def name(self):
        """Gets the name of this AbstractApplicationUserUpdate.

            The user name is used to identify the application user in administrative interfaces.

        :return: The name of this AbstractApplicationUserUpdate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AbstractApplicationUserUpdate.

            The user name is used to identify the application user in administrative interfaces.

        :param name: The name of this AbstractApplicationUserUpdate.
        :type: str
        """
        if name is not None and len(name) > 256:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `256`")

        self._name = name
    
    @property
    def request_limit(self):
        """Gets the request_limit of this AbstractApplicationUserUpdate.

            The request limit defines the maximum number of API request accepted within 2 minutes. This limit can only be changed with special privileges.

        :return: The request_limit of this AbstractApplicationUserUpdate.
        :rtype: int
        """
        return self._request_limit

    @request_limit.setter
    def request_limit(self, request_limit):
        """Sets the request_limit of this AbstractApplicationUserUpdate.

            The request limit defines the maximum number of API request accepted within 2 minutes. This limit can only be changed with special privileges.

        :param request_limit: The request_limit of this AbstractApplicationUserUpdate.
        :type: int
        """

        self._request_limit = request_limit
    
    @property
    def state(self):
        """Gets the state of this AbstractApplicationUserUpdate.

            

        :return: The state of this AbstractApplicationUserUpdate.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this AbstractApplicationUserUpdate.

            

        :param state: The state of this AbstractApplicationUserUpdate.
        :type: CreationEntityState
        """

        self._state = state
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractApplicationUserUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractApplicationUserUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class Condition:

    swagger_types = {
    
        'condition_type': 'int',
        'id': 'int',
        'linked_space_id': 'int',
        'name': 'str',
        'planned_purge_date': 'datetime',
        'state': 'CreationEntityState',
        'version': 'int',
    }

    attribute_map = {
        'condition_type': 'conditionType','id': 'id','linked_space_id': 'linkedSpaceId','name': 'name','planned_purge_date': 'plannedPurgeDate','state': 'state','version': 'version',
    }

    
    _condition_type = None
    _id = None
    _linked_space_id = None
    _name = None
    _planned_purge_date = None
    _state = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.condition_type = kwargs.get('condition_type', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.name = kwargs.get('name', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.state = kwargs.get('state', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def condition_type(self):
        """Gets the condition_type of this Condition.

            The selected condition type defines how the configuration is applied to the transactions.

        :return: The condition_type of this Condition.
        :rtype: int
        """
        return self._condition_type

    @condition_type.setter
    def condition_type(self, condition_type):
        """Sets the condition_type of this Condition.

            The selected condition type defines how the configuration is applied to the transactions.

        :param condition_type: The condition_type of this Condition.
        :type: int
        """

        self._condition_type = condition_type
    
    @property
    def id(self):
        """Gets the id of this Condition.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this Condition.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Condition.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this Condition.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this Condition.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this Condition.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this Condition.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this Condition.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def name(self):
        """Gets the name of this Condition.

            The condition name is used internally to identify the condition. For example the name is used within search fields and hence it should be distinct and descriptive.

        :return: The name of this Condition.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Condition.

            The condition name is used internally to identify the condition. For example the name is used within search fields and hence it should be distinct and descriptive.

        :param name: The name of this Condition.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this Condition.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this Condition.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this Condition.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this Condition.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def state(self):
        """Gets the state of this Condition.

            

        :return: The state of this Condition.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Condition.

            

        :param state: The state of this Condition.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def version(self):
        """Gets the version of this Condition.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this Condition.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Condition.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this Condition.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(Condition, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, Condition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class TransactionEnvironmentSelectionStrategy(Enum):
    
    FORCE_TEST_ENVIRONMENT = "FORCE_TEST_ENVIRONMENT"
    FORCE_PRODUCTION_ENVIRONMENT = "FORCE_PRODUCTION_ENVIRONMENT"
    USE_CONFIGURATION = "USE_CONFIGURATION"




# coding: utf-8
import pprint
import six
from enum import Enum



class LineItemAttribute:

    swagger_types = {
    
        'label': 'str',
        'value': 'str',
    }

    attribute_map = {
        'label': 'label','value': 'value',
    }

    
    _label = None
    _value = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.label = kwargs.get('label', None)
        self.value = kwargs.get('value', None)
        

    
    @property
    def label(self):
        """Gets the label of this LineItemAttribute.

            

        :return: The label of this LineItemAttribute.
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this LineItemAttribute.

            

        :param label: The label of this LineItemAttribute.
        :type: str
        """
        if label is not None and len(label) > 512:
            raise ValueError("Invalid value for `label`, length must be less than or equal to `512`")

        self._label = label
    
    @property
    def value(self):
        """Gets the value of this LineItemAttribute.

            

        :return: The value of this LineItemAttribute.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this LineItemAttribute.

            

        :param value: The value of this LineItemAttribute.
        :type: str
        """
        if value is not None and len(value) > 512:
            raise ValueError("Invalid value for `value`, length must be less than or equal to `512`")

        self._value = value
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(LineItemAttribute, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, LineItemAttribute):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractWebhookUrlUpdate:

    swagger_types = {
    
        'name': 'str',
        'state': 'CreationEntityState',
        'url': 'str',
    }

    attribute_map = {
        'name': 'name','state': 'state','url': 'url',
    }

    
    _name = None
    _state = None
    _url = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.name = kwargs.get('name', None)
        self.state = kwargs.get('state', None)
        self.url = kwargs.get('url', None)
        

    
    @property
    def name(self):
        """Gets the name of this AbstractWebhookUrlUpdate.

            The URL name is used internally to identify the URL in administrative interfaces. For example it is used within search fields and hence it should be distinct and descriptive.

        :return: The name of this AbstractWebhookUrlUpdate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AbstractWebhookUrlUpdate.

            The URL name is used internally to identify the URL in administrative interfaces. For example it is used within search fields and hence it should be distinct and descriptive.

        :param name: The name of this AbstractWebhookUrlUpdate.
        :type: str
        """
        if name is not None and len(name) > 50:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `50`")

        self._name = name
    
    @property
    def state(self):
        """Gets the state of this AbstractWebhookUrlUpdate.

            

        :return: The state of this AbstractWebhookUrlUpdate.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this AbstractWebhookUrlUpdate.

            

        :param state: The state of this AbstractWebhookUrlUpdate.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def url(self):
        """Gets the url of this AbstractWebhookUrlUpdate.

            The URL to which the HTTP requests are sent to. An example URL could look like https://www.example.com/some/path?some-query-parameter=value.

        :return: The url of this AbstractWebhookUrlUpdate.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this AbstractWebhookUrlUpdate.

            The URL to which the HTTP requests are sent to. An example URL could look like https://www.example.com/some/path?some-query-parameter=value.

        :param url: The url of this AbstractWebhookUrlUpdate.
        :type: str
        """
        if url is not None and len(url) > 500:
            raise ValueError("Invalid value for `url`, length must be less than or equal to `500`")
        if url is not None and len(url) < 9:
            raise ValueError("Invalid value for `url`, length must be greater than or equal to `9`")

        self._url = url
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractWebhookUrlUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractWebhookUrlUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class DocumentTemplate:

    swagger_types = {
    
        'default_template': 'bool',
        'delivery_enabled': 'bool',
        'id': 'int',
        'linked_space_id': 'int',
        'name': 'str',
        'planned_purge_date': 'datetime',
        'space_id': 'int',
        'state': 'CreationEntityState',
        'template_resource': 'ResourcePath',
        'type': 'int',
        'version': 'int',
    }

    attribute_map = {
        'default_template': 'defaultTemplate','delivery_enabled': 'deliveryEnabled','id': 'id','linked_space_id': 'linkedSpaceId','name': 'name','planned_purge_date': 'plannedPurgeDate','space_id': 'spaceId','state': 'state','template_resource': 'templateResource','type': 'type','version': 'version',
    }

    
    _default_template = None
    _delivery_enabled = None
    _id = None
    _linked_space_id = None
    _name = None
    _planned_purge_date = None
    _space_id = None
    _state = None
    _template_resource = None
    _type = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.default_template = kwargs.get('default_template', None)
        self.delivery_enabled = kwargs.get('delivery_enabled', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.name = kwargs.get('name', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.space_id = kwargs.get('space_id', None)
        self.state = kwargs.get('state', None)
        self.template_resource = kwargs.get('template_resource', None)
        self.type = kwargs.get('type', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def default_template(self):
        """Gets the default_template of this DocumentTemplate.

            The default document template is used whenever no specific template is specified for a particular template type.

        :return: The default_template of this DocumentTemplate.
        :rtype: bool
        """
        return self._default_template

    @default_template.setter
    def default_template(self, default_template):
        """Sets the default_template of this DocumentTemplate.

            The default document template is used whenever no specific template is specified for a particular template type.

        :param default_template: The default_template of this DocumentTemplate.
        :type: bool
        """

        self._default_template = default_template
    
    @property
    def delivery_enabled(self):
        """Gets the delivery_enabled of this DocumentTemplate.

            

        :return: The delivery_enabled of this DocumentTemplate.
        :rtype: bool
        """
        return self._delivery_enabled

    @delivery_enabled.setter
    def delivery_enabled(self, delivery_enabled):
        """Sets the delivery_enabled of this DocumentTemplate.

            

        :param delivery_enabled: The delivery_enabled of this DocumentTemplate.
        :type: bool
        """

        self._delivery_enabled = delivery_enabled
    
    @property
    def id(self):
        """Gets the id of this DocumentTemplate.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this DocumentTemplate.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DocumentTemplate.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this DocumentTemplate.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this DocumentTemplate.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this DocumentTemplate.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this DocumentTemplate.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this DocumentTemplate.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def name(self):
        """Gets the name of this DocumentTemplate.

            

        :return: The name of this DocumentTemplate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DocumentTemplate.

            

        :param name: The name of this DocumentTemplate.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this DocumentTemplate.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this DocumentTemplate.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this DocumentTemplate.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this DocumentTemplate.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def space_id(self):
        """Gets the space_id of this DocumentTemplate.

            

        :return: The space_id of this DocumentTemplate.
        :rtype: int
        """
        return self._space_id

    @space_id.setter
    def space_id(self, space_id):
        """Sets the space_id of this DocumentTemplate.

            

        :param space_id: The space_id of this DocumentTemplate.
        :type: int
        """

        self._space_id = space_id
    
    @property
    def state(self):
        """Gets the state of this DocumentTemplate.

            

        :return: The state of this DocumentTemplate.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this DocumentTemplate.

            

        :param state: The state of this DocumentTemplate.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def template_resource(self):
        """Gets the template_resource of this DocumentTemplate.

            

        :return: The template_resource of this DocumentTemplate.
        :rtype: ResourcePath
        """
        return self._template_resource

    @template_resource.setter
    def template_resource(self, template_resource):
        """Sets the template_resource of this DocumentTemplate.

            

        :param template_resource: The template_resource of this DocumentTemplate.
        :type: ResourcePath
        """

        self._template_resource = template_resource
    
    @property
    def type(self):
        """Gets the type of this DocumentTemplate.

            

        :return: The type of this DocumentTemplate.
        :rtype: int
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DocumentTemplate.

            

        :param type: The type of this DocumentTemplate.
        :type: int
        """

        self._type = type
    
    @property
    def version(self):
        """Gets the version of this DocumentTemplate.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this DocumentTemplate.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this DocumentTemplate.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this DocumentTemplate.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(DocumentTemplate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, DocumentTemplate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class ShopifyRecurringOrderUpdateRequest:

    swagger_types = {
    
        'execution_date': 'datetime',
        'recurring_order_id': 'int',
    }

    attribute_map = {
        'execution_date': 'executionDate','recurring_order_id': 'recurringOrderId',
    }

    
    _execution_date = None
    _recurring_order_id = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.execution_date = kwargs.get('execution_date', None)
        self.recurring_order_id = kwargs.get('recurring_order_id', None)
        

    
    @property
    def execution_date(self):
        """Gets the execution_date of this ShopifyRecurringOrderUpdateRequest.

            

        :return: The execution_date of this ShopifyRecurringOrderUpdateRequest.
        :rtype: datetime
        """
        return self._execution_date

    @execution_date.setter
    def execution_date(self, execution_date):
        """Sets the execution_date of this ShopifyRecurringOrderUpdateRequest.

            

        :param execution_date: The execution_date of this ShopifyRecurringOrderUpdateRequest.
        :type: datetime
        """

        self._execution_date = execution_date
    
    @property
    def recurring_order_id(self):
        """Gets the recurring_order_id of this ShopifyRecurringOrderUpdateRequest.

            

        :return: The recurring_order_id of this ShopifyRecurringOrderUpdateRequest.
        :rtype: int
        """
        return self._recurring_order_id

    @recurring_order_id.setter
    def recurring_order_id(self, recurring_order_id):
        """Sets the recurring_order_id of this ShopifyRecurringOrderUpdateRequest.

            

        :param recurring_order_id: The recurring_order_id of this ShopifyRecurringOrderUpdateRequest.
        :type: int
        """

        self._recurring_order_id = recurring_order_id
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ShopifyRecurringOrderUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ShopifyRecurringOrderUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
